==> rivendell-3.6.6.tar.gz: rivendell-3.6.6/rdlogin/rdlogin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0">
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation type="obsolete">RDLogin - Stanice:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation type="obsolete">rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Nynější uživatel: neznámý</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation>&amp;Uživatelské jméno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation>He&amp;slo:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation>&amp;Nastavit uživatele</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation>&amp;Výchozí
uživatel</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Z&amp;rušit</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation type="obsolete">Nynější uživatel:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ungültiges Paßwort!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current User</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> rivendell-4.0.0rc0.tar.gz: rivendell-4.0.0rc0/rdlogin/rdlogin_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1">
<context>
    <name>MainWidget</name>
    <message>
        <source>RDLogin - Station:</source>
        <translation type="obsolete">RDLogin - Stanice:</translation>
    </message>
    <message>
        <source>rdlogin : </source>
        <translation type="obsolete">rdlogin :</translation>
    </message>
    <message>
        <source>Can&apos;t Connect</source>
        <translation type="obsolete">Nelze spojit</translation>
    </message>
    <message>
        <source>Current User: unknown</source>
        <translation>Nynější uživatel: neznámý</translation>
    </message>
    <message>
        <source>&amp;Username:</source>
        <translation type="obsolete">&amp;Uživatelské jméno:</translation>
    </message>
    <message>
        <source>&amp;Password:</source>
        <translation type="obsolete">He&amp;slo:</translation>
    </message>
    <message>
        <source>&amp;Set User</source>
        <translation type="obsolete">&amp;Nastavit uživatele</translation>
    </message>
    <message>
        <source>&amp;Default
User</source>
        <translation type="obsolete">&amp;Výchozí
uživatel</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation type="obsolete">Z&amp;rušit</translation>
    </message>
    <message>
        <source>Current User:</source>
        <translation type="obsolete">Nynější uživatel:</translation>
    </message>
    <message>
        <source>RDLogin</source>
        <translation>RDLogin</translation>
    </message>
    <message>
        <source>Invalid Password!</source>
        <translation type="obsolete">Ungültiges Paßwort!</translation>
    </message>
    <message>
        <source>Invalid Username or Password!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Error</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Unknown command option</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Current User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Username:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Password:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Set User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Default
User</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
